pub struct Text(/* private fields */);Expand description
Represents formatted text in Minecraft’s JSON text format.
Text is used in various places such as chat, window titles, disconnect messages, written books, signs, and more.
For more information, see the relevant Minecraft Wiki article.
Examples
With IntoText in scope, you can write the following:
use chunkedge_text::{Color, IntoText, Text};
let txt = "The text is ".into_text()
+ "Red".color(Color::RED)
+ ", "
+ "Green".color(Color::GREEN)
+ ", and also "
+ "Blue".color(Color::BLUE)
+ "! And maybe even "
+ "Italic".italic()
+ ".";
assert_eq!(
txt.to_string(),
r#"{"text":"The text is ","extra":[{"text":"Red","color":"red"},{"text":", "},{"text":"Green","color":"green"},{"text":", and also "},{"text":"Blue","color":"blue"},{"text":"! And maybe even "},{"text":"Italic","italic":true},{"text":"."}]}"#
);Implementations
Sourceimpl Text
impl Text
Sourcepub fn is_plain(&self) -> bool
pub fn is_plain(&self) -> bool
Is this a simple text object without any extra children or formatting?
(No options set and only TextContent::Text)
Sourcepub fn translate<K, W>(
key: K,
with: W,
fallback: Option<Cow<'static, str>>,
) -> Text
pub fn translate<K, W>( key: K, with: W, fallback: Option<Cow<'static, str>>, ) -> Text
Create translated text based on the given translation key, with extra text components to be inserted into the slots of the translation text.
Sourcepub fn score<N, O>(
name: N,
objective: O,
value: Option<Cow<'static, str>>,
) -> Text
pub fn score<N, O>( name: N, objective: O, value: Option<Cow<'static, str>>, ) -> Text
Create a score from the scoreboard with an optional custom value.
Sourcepub fn selector<S>(selector: S, separator: Option<Text>) -> Text
pub fn selector<S>(selector: S, separator: Option<Text>) -> Text
Creates a text component for selecting entity names with an optional custom separator.
Sourcepub fn keybind<K>(keybind: K) -> Text
pub fn keybind<K>(keybind: K) -> Text
Creates a text component for a keybind. The keybind should be a valid
keybind identifier.
Sourcepub fn block_nbt<B, N>(
block: B,
nbt: N,
interpret: Option<bool>,
separator: Option<Text>,
) -> Text
pub fn block_nbt<B, N>( block: B, nbt: N, interpret: Option<bool>, separator: Option<Text>, ) -> Text
Creates a text component for a block NBT tag.
Sourcepub fn entity_nbt<E, N>(
entity: E,
nbt: N,
interpret: Option<bool>,
separator: Option<Text>,
) -> Text
pub fn entity_nbt<E, N>( entity: E, nbt: N, interpret: Option<bool>, separator: Option<Text>, ) -> Text
Creates a text component for an entity NBT tag.
Sourcepub fn storage_nbt<S, N>(
storage: S,
nbt: N,
interpret: Option<bool>,
separator: Option<Text>,
) -> Text
pub fn storage_nbt<S, N>( storage: S, nbt: N, interpret: Option<bool>, separator: Option<Text>, ) -> Text
Creates a text component for a command storage NBT tag.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the text contains no characters. Returns false
otherwise.
Sourcepub fn to_legacy_lossy(&self) -> String
pub fn to_legacy_lossy(&self) -> String
Converts the Text object to a plain string with the legacy formatting ( and format codes)
Removes everything that can’t be represented with a  and a modifier.
Any colors not on the the legacy color list will be replaced with their closest equivalent.