#[repr(transparent)]pub struct VarLong(pub i64);Expand description
An i64 encoded with variable length.
Tuple Fields
0: i64Implementations
Sourceimpl VarLong
impl VarLong
Sourcepub const MAX_SIZE: usize = 10
pub const MAX_SIZE: usize = 10
The maximum number of bytes a VarLong can occupy when read from and
written to the Minecraft protocol.
Sourcepub fn written_size(self) -> usize
pub fn written_size(self) -> usize
Returns the exact number of bytes this varlong will write when
Encode::encode is called, assuming no error occurs.
This is the size of “canonical” (non-padded) encoding for this
value, not necessarily the number of bytes that were consumed
while decoding it. Minecraft VarLongs may be padded by using
more continuation bytes than the value requires, so callers that
need the decoded wire length should compare the input slice length
before and after decoding instead.